@@ -35,9 +35,7 @@
    exception statement from your version. */
 
 
-#include <glib.h>
-#include <npapi.h>
-#include <npupp.h>
+// System includes
 #include <string.h>
 #include <unistd.h>
 #include <stdlib.h>
@@ -45,6 +43,14 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 
+// Netscape plugin API includes
+#include <npapi.h>
+#include <npupp.h>
+
+// GLib includes
+#include <glib.h>
+
+// gcjwebplugin includes
 #include "config.h"
 #include "pluginDebug.h"
 #include "pluginMeta.h"
@@ -287,7 +293,9 @@ GCJ_SetWindow (NPP instance, NPWindow* window)
 	    }
 	  else
 	    {
-	      PLUGIN_DEBUG ("GCJ_SetWindow: gcjappletviewer not spawned\n");
+	      PLUGIN_DEBUG ("GCJ_SetWindow: "
+			    GCJAPPLETVIEWER_EXECUTABLE
+			    " not spawned\n");
 	    }
 	}
       else
@@ -507,11 +515,13 @@ NP_Initialize(NPNetscapeFuncs* browserTable, NPPluginFuncs* pluginTable)
     }
   
   GError *err = NULL;
-  gchar *command_line [3] = { "gcjappletviewer",
-			      g_strdup_printf ("--plugin=%s,%s",
-					       pipename_in,
-					       pipename_out),
-			      NULL };
+  gchar *command_line [3] = {
+    GCJAPPLETVIEWER_EXECUTABLE,
+    g_strdup_printf ("--plugin=%s,%s",
+		     pipename_in,
+		     pipename_out),
+    NULL
+  };
 
   if (!g_spawn_async (NULL,
 		      command_line,
@@ -526,7 +536,9 @@ NP_Initialize(NPNetscapeFuncs* browserTable, NPPluginFuncs* pluginTable)
       return NPERR_GENERIC_ERROR;
     }
 
-  g_printerr ("Spawned gcjappletviewer successfully.\n");
+  g_printerr ("Spawned "
+	      GCJAPPLETVIEWER_EXECUTABLE
+	      " successfully.\n");
 
   output_to_appletviewer = g_io_channel_new_file (pipename_in, "w", &err);
   if (!output_to_appletviewer)
