@@ -28,7 +28,6 @@ import java.io.InputStreamReader;
 import java.io.StreamTokenizer;
 import java.net.MalformedURLException;
 import java.net.URL;
-import java.net.URLConnection;
 import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.Iterator;
@@ -44,7 +43,6 @@ class AppletTag
   String archivesList = "";
   ArrayList archives = new ArrayList();
   HashMap parameters = new HashMap();
-  Dimension dimensions = new Dimension(0, 0);
 
   // documentbase is not specified in an applet tag but we keep it
   // here anyway, for convenience.
@@ -97,7 +95,6 @@ class AppletTag
       }
     this.parameters.put("width", Integer.toString(dimensions.width));
     this.parameters.put("height", Integer.toString(dimensions.height));
-    this.dimensions = dimensions;
   }
 
   // Construct an applet tag object from an HTML stream.
@@ -106,7 +103,6 @@ class AppletTag
   {
     this.documentbase = documentbase;
     this.encoding = encoding;
-    dimensions = new Dimension(0, 0);
 
     while (tagTokenizer.nextToken() != '>')
       {
@@ -128,21 +124,20 @@ class AppletTag
 		tagTokenizer.nextToken();
 		tagTokenizer.nextToken();
 		if (tagTokenizer.ttype == StreamTokenizer.TT_NUMBER)
-		  dimensions.width = (int) tagTokenizer.nval;
+		  this.parameters.put("width",
+				      Integer.toString((int) tagTokenizer.nval));
 		else
-		  dimensions.width = Integer.parseInt(tagTokenizer.sval);
-		this.parameters.put("width", Integer.toString(dimensions.width));
+		  this.parameters.put("width", tagTokenizer.sval);
 	      }
 	    else if (tagTokenizer.sval.equals("height"))
 	      {
 		tagTokenizer.nextToken();
 		tagTokenizer.nextToken();
 		if (tagTokenizer.ttype == StreamTokenizer.TT_NUMBER)
-		  dimensions.height = (int) tagTokenizer.nval;
+		  this.parameters.put("height",
+				      Integer.toString((int) tagTokenizer.nval));
 		else
-		  dimensions.height = Integer.parseInt(tagTokenizer.sval);
-		this.parameters.put("height",
-		                    Integer.toString(dimensions.height));
+		  this.parameters.put("height", tagTokenizer.sval);
 	      }
 	  }
       }
@@ -274,7 +269,7 @@ class AppletTag
     tagTokenizer.lowerCaseMode(false);
 
     tagTokenizer.nextToken();
-    if (tagTokenizer.ttype == tagTokenizer.TT_NUMBER)
+    if (tagTokenizer.ttype == StreamTokenizer.TT_NUMBER)
       {
 	// Remove nval's scale.
 	int unscaled_nval = (int) tagTokenizer.nval;
@@ -367,13 +362,13 @@ class AppletTag
     tagTokenizer.wordChars('_', '_');
 
     token = tagTokenizer.nextToken();
-    while (token != tagTokenizer.TT_EOF)
+    while (token != StreamTokenizer.TT_EOF)
       {
 	// Start of an HTML tag.
 	if (token == '<')
 	  {
 	    token = tagTokenizer.nextToken();
-	    if (token == tagTokenizer.TT_WORD)
+	    if (token == StreamTokenizer.TT_WORD)
 	      {
 		// An APPLET tag.
 		if (tagTokenizer.sval.equals("applet"))
@@ -402,7 +397,7 @@ class AppletTag
 		  {
 		    token = tagTokenizer.nextToken();
 
-		    if (token == tagTokenizer.TT_WORD)
+		    if (token == StreamTokenizer.TT_WORD)
 		      {
 			if (currentTag instanceof AppletTag)
 			  {
@@ -430,10 +425,10 @@ class AppletTag
 
   public String toString()
   {
-    return "  name=" + name + "\n" + "  code=" + code + "\n" + "  codebase="
-           + codebase + "\n" + "  archive=" + archives + "\n"
-           + "  parameters=" + parameters + "\n" + "  dimensions="
-           + dimensions + "\n" + "  documentbase=" + documentbase + "\n";
+    return ("  name=" + name + "\n" + "  code=" + code + "\n" + "  codebase="
+	    + codebase + "\n" + "  archive=" + archives + "\n"
+	    + "  parameters=" + parameters + "\n" + "  documentbase="
+	    + documentbase + "\n");
   }
 }
 
@@ -445,7 +440,6 @@ class EmbedTag extends AppletTag
   {
     this.documentbase = documentbase;
     this.encoding = encoding;
-    dimensions = new Dimension(0, 0);
 
     // In an EMBED tag, a parameter is any non-standard attribute.  This
     // is a problem for applets that take parameters named "code",
@@ -571,21 +565,20 @@ class EmbedTag extends AppletTag
 		tagTokenizer.nextToken();
 		tagTokenizer.nextToken();
 		if (tagTokenizer.ttype == StreamTokenizer.TT_NUMBER)
-		  dimensions.width = (int) tagTokenizer.nval;
+		  this.parameters.put("width",
+				      Integer.toString((int) tagTokenizer.nval));
 		else
-		  dimensions.width = Integer.parseInt(tagTokenizer.sval);
-		this.parameters.put("width", Integer.toString(dimensions.width));
+		  this.parameters.put("width", tagTokenizer.sval);
 	      }
 	    else if (tagTokenizer.sval.equals("height"))
 	      {
 		tagTokenizer.nextToken();
 		tagTokenizer.nextToken();
 		if (tagTokenizer.ttype == StreamTokenizer.TT_NUMBER)
-		  dimensions.height = (int) tagTokenizer.nval;
+		  this.parameters.put("height",
+				      Integer.toString((int) tagTokenizer.nval));
 		else
-		  dimensions.height = Integer.parseInt(tagTokenizer.sval);
-		this.parameters.put("height",
-		                    Integer.toString(dimensions.height));
+		  this.parameters.put("height", tagTokenizer.sval);
 	      }
 	    else if (! tagTokenizer.sval.equals("align")
 	             && ! tagTokenizer.sval.equals("alt")
@@ -625,7 +618,6 @@ class ObjectTag extends AppletTag
   {
     this.documentbase = documentbase;
     this.encoding = encoding;
-    dimensions = new Dimension(0, 0);
 
     while (tagTokenizer.nextToken() != '>')
       {
@@ -639,21 +631,20 @@ class ObjectTag extends AppletTag
 		tagTokenizer.nextToken();
 		tagTokenizer.nextToken();
 		if (tagTokenizer.ttype == StreamTokenizer.TT_NUMBER)
-		  dimensions.width = (int) tagTokenizer.nval;
+		  this.parameters.put("width",
+				      Integer.toString((int) tagTokenizer.nval));
 		else
-		  dimensions.width = Integer.parseInt(tagTokenizer.sval);
-		this.parameters.put("width", Integer.toString(dimensions.width));
+		  this.parameters.put("width", tagTokenizer.sval);
 	      }
 	    else if (tagTokenizer.sval.equals("height"))
 	      {
 		tagTokenizer.nextToken();
 		tagTokenizer.nextToken();
 		if (tagTokenizer.ttype == StreamTokenizer.TT_NUMBER)
-		  dimensions.height = (int) tagTokenizer.nval;
+		  this.parameters.put("height",
+				      Integer.toString((int) tagTokenizer.nval));
 		else
-		  dimensions.height = Integer.parseInt(tagTokenizer.sval);
-		this.parameters.put("height",
-		                    Integer.toString(dimensions.height));
+		  this.parameters.put("height", tagTokenizer.sval);
 	      }
 	  }
       }
@@ -768,7 +759,6 @@ class AppTag extends AppletTag
   {
     this.documentbase = documentbase;
     this.encoding = encoding;
-    dimensions = new Dimension(0, 0);
 
     while (tagTokenizer.nextToken() != '>')
       {
@@ -783,21 +773,20 @@ class AppTag extends AppletTag
 		tagTokenizer.nextToken();
 		tagTokenizer.nextToken();
 		if (tagTokenizer.ttype == StreamTokenizer.TT_NUMBER)
-		  dimensions.width = (int) tagTokenizer.nval;
+		  this.parameters.put("width",
+				      Integer.toString((int) tagTokenizer.nval));
 		else
-		  dimensions.width = Integer.parseInt(tagTokenizer.sval);
-		this.parameters.put("width", Integer.toString(dimensions.width));
+		  this.parameters.put("width", tagTokenizer.sval);
 	      }
 	    else if (tagTokenizer.sval.equals("height"))
 	      {
 		tagTokenizer.nextToken();
 		tagTokenizer.nextToken();
 		if (tagTokenizer.ttype == StreamTokenizer.TT_NUMBER)
-		  dimensions.height = (int) tagTokenizer.nval;
+		  this.parameters.put("height",
+				      Integer.toString((int) tagTokenizer.nval));
 		else
-		  dimensions.height = Integer.parseInt(tagTokenizer.sval);
-		this.parameters.put("height",
-		                    Integer.toString(dimensions.height));
+		  this.parameters.put("height", tagTokenizer.sval);
 	      }
 	  }
       }
