@@ -34,19 +34,18 @@ import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.HashMap;
 import java.util.Iterator;
-import java.util.MissingResourceException;
 import java.util.LinkedList;
 import java.util.List;
+import java.util.MissingResourceException;
 import java.util.ResourceBundle;
-import java.util.Vector;
 
 
 class AppletViewer
 {
   /**
-   * The localized strings are kept in a separate file
+   * The localized strings are kept in a separate file.
    */
-  public static ResourceBundle messages = ResourceBundle.getBundle
+  public static final ResourceBundle messages = ResourceBundle.getBundle
     ("gnu.gcjwebplugin.locale.MessagesBundle");
 
   private static HashMap classLoaderCache = new HashMap();
@@ -300,7 +299,7 @@ class AppletViewer
     if (dimensions.width < 0)
       dimensions.width = (int) (1.6 * dimensions.height);
 
-    System.setSecurityManager(new AppletSecurityManager(pluginMode));
+    //System.setSecurityManager(new AppletSecurityManager(pluginMode));
     
     if (pluginMode)
       {
