@@ -29,8 +29,6 @@ import java.io.OutputStream;
 import java.io.OutputStreamWriter;
 import java.io.PrintStream;
 import java.net.MalformedURLException;
-import java.net.URL;
-import java.net.URLClassLoader;
 import java.util.HashMap;
 
 
@@ -88,9 +86,6 @@ class PluginAppletViewer
 	      appletWindows.put(key, new PluginAppletWindow());
 
 	    currentWindow = (PluginAppletWindow) appletWindows.get(key);
-
-	    // Show java console.
-	    consoleDialog.show();
 	  }
 	else if (message.startsWith("tag"))
 	  {
