@@ -23,13 +23,14 @@ package gnu.gcjwebplugin;
 import gnu.java.awt.EmbeddedWindow;
 import java.applet.Applet;
 import java.applet.AppletContext;
+import java.awt.AWTEvent;
 import java.awt.BorderLayout;
 import java.awt.Component;
 import java.awt.Dimension;
+import java.awt.Toolkit;
 import java.io.IOException;
 import java.io.StreamTokenizer;
 import java.io.StringReader;
-import java.io.Writer;
 import java.net.MalformedURLException;
 import java.net.URL;
 import java.util.HashMap;
@@ -84,15 +85,21 @@ class PluginAppletWindow extends EmbeddedWindow
 
     AppletContext context = (AppletContext) contexts.get(tag.codebase);
     ((PluginAppletContext) context).addApplet(applet);
-    applet.setStub(new CommonAppletStub(tag, context));
+    applet.setStub(new CommonAppletStub(tag, context, applet));
 
     String testWindowCount = System.getProperty("gnu.gcjwebplugin.test.windowCount");
 
     if (testWindowCount == null)
       {
-	setVisible(true);
+        // Synchronize on the system event queue when showing and
+        // initializing the applet so that it doesn't receive events
+        // before it has been initialized.
+        synchronized (Toolkit.getDefaultToolkit ().getSystemEventQueue ())
+          {
+            setVisible (true);
+            applet.init ();
+          }
 
-	applet.init();
 	applet.validate();
 	applet.start();
       }
@@ -126,14 +133,7 @@ class PluginAppletWindow extends EmbeddedWindow
     Component c = this.getComponent(0);
     if (c != null)
       {
-	Dimension cs = null;
-
-	if (tag != null)
-	  cs = tag.dimensions;
-
-	if (cs == null)
-	  cs = getSize();
-
+	Dimension cs = getSize();
 	c.setBounds(0, 0, cs.width, cs.height);
       }
   }
